@@ -5,9 +5,19 @@ from django.contrib import admin
 from django.contrib.admin.views.decorators import staff_member_required
 from django.urls import re_path, reverse_lazy
 
+from core_main_app.admin import core_admin_site
+
+from core_composer_app.components.bucket.models import Bucket
+from core_composer_app.components.type.admin_site import CustomTypeAdmin
+from core_composer_app.components.type.models import Type
+from core_composer_app.components.type_version_manager.admin_site import (
+    CustomTypeVersionManagerAdmin,
+)
+from core_composer_app.components.type_version_manager.models import TypeVersionManager
 from core_composer_app.views.admin import views as admin_views, ajax as admin_ajax
 from core_composer_app.views.admin.ajax import EditBucketView
-from core_main_app.views.common.ajax import EditTemplateVersionManagerView
+from core_composer_app.views.user.ajax import EditTypeVersionManagerView
+
 
 parser_url = []
 if "core_parser_app" in settings.INSTALLED_APPS:
@@ -18,7 +28,7 @@ if "core_parser_app" in settings.INSTALLED_APPS:
             r"^type/modules/(?P<pk>\w+)",
             staff_member_required(
                 admin_parser_views.ManageModulesAdminView.as_view(
-                    back_to_previous_url="admin:core_composer_app_manage_type_versions"
+                    back_to_previous_url="core-admin:core_composer_app_manage_type_versions"
                 )
             ),
             name="core_composer_app_type_modules",
@@ -30,8 +40,8 @@ admin_urls = [
     re_path(
         r"^type/(?P<pk>[\w-]+)/edit/$",
         staff_member_required(
-            EditTemplateVersionManagerView.as_view(
-                success_url=reverse_lazy("admin:core_composer_app_types")
+            EditTypeVersionManagerView.as_view(
+                success_url=reverse_lazy("core-admin:core_composer_app_types")
             )
         ),
         name="core_composer_app_edit_type",
@@ -77,5 +87,9 @@ admin_urls = [
     ),
 ]
 
-urls = admin.site.get_urls()
-admin.site.get_urls = lambda: admin_urls + urls + parser_url
+admin.site.register(Bucket)
+admin.site.register(Type, CustomTypeAdmin)
+admin.site.register(TypeVersionManager, CustomTypeVersionManagerAdmin)
+
+urls = core_admin_site.get_urls()
+core_admin_site.get_urls = lambda: parser_url + admin_urls + urls
