@@ -1,16 +1,31 @@
 """
 Type Version Manager API
 """
-from core_composer_app.components.bucket import api as bucket_api
-from core_composer_app.components.type import api as type_api
-from core_composer_app.components.type_version_manager.models import TypeVersionManager
 from core_main_app.access_control.api import is_superuser
 from core_main_app.access_control.decorators import access_control
-from core_main_app.components.template import api as template_api
+from core_main_app.components.template.access_control import can_read
 from core_main_app.components.template.access_control import can_read_global
 from core_main_app.components.template_version_manager.access_control import can_write
 from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.components.version_manager.utils import get_latest_version_name
+import core_main_app.commons.exceptions as exceptions
+from core_composer_app.components.bucket import api as bucket_api
+from core_composer_app.components.type import api as type_api
+from core_composer_app.components.type_version_manager.models import TypeVersionManager
+
+
+@access_control(can_read)
+def get_by_id(version_manager_id, request):
+    """Get a type version manager by its id.
+
+    Args:
+        version_manager_id:
+        request:
+
+    Returns:
+
+    """
+    return TypeVersionManager.get_by_id(version_manager_id)
 
 
 @access_control(can_write)
@@ -29,23 +44,24 @@ def insert(type_version_manager, type_object, request, list_bucket_ids=None):
     # save the type in database
     type_api.upsert(type_object, request=request)
     try:
-        # insert the initial template in the version manager
-        version_manager_api.insert_version(
-            type_version_manager, type_object, request=request
-        )
-        # insert the version manager in database
+        # create version manager
         version_manager_api.upsert(type_version_manager, request=request)
+        # set version manager
+        type_object.version_manager = type_version_manager
+        # insert the initial template in the version manager
+        if len(type_version_manager.versions) == 0:
+            type_object.is_current = True
         # Add to the selected buckets
         bucket_api.add_type_to_buckets(type_version_manager, list_bucket_ids)
-        # get type display name
-        display_name = get_latest_version_name(type_version_manager)
-        # update saved template
-        template_api.set_display_name(type_object, display_name, request=request)
-        # update saved type
+        # update display name
+        type_object.display_name = get_latest_version_name(type_version_manager)
+        # save type
+        type_object.save()
+        # return version manager
         return type_version_manager
-    except Exception as e:
-        type_api.delete(type_object, request=request)
-        raise e
+    except Exception as exception:
+        type_object.delete()
+        raise exception
 
 
 @access_control(can_read_global)
@@ -104,7 +120,7 @@ def get_no_buckets_types(request):
     # build list of types
     bucket_types = []
     for bucket in bucket_api.get_all():
-        bucket_types += bucket.types
+        bucket_types += bucket.types.all()
 
     all_types = get_global_version_managers(request=request)
     no_bucket_types = [
