@@ -1,11 +1,11 @@
 """Composer Admin Forms
 """
 from django import forms
+from django.forms import ModelForm
 
+from core_main_app.commons.validators import ExtensionValidator
 from core_composer_app.components.bucket import api as bucket_api
 from core_composer_app.components.bucket.models import Bucket
-from django_mongoengine.forms import DocumentForm
-from core_main_app.commons.validators import ExtensionValidator
 
 
 class BucketForm(forms.Form):
@@ -68,7 +68,11 @@ class EditTypeBucketsForm(forms.Form):
     )
 
 
-class EditBucketForm(DocumentForm):
+class EditBucketForm(ModelForm):
+    """
+    Edit Bucket Form
+    """
+
     label = forms.CharField(
         label="Label",
         widget=forms.TextInput(
@@ -76,6 +80,8 @@ class EditBucketForm(DocumentForm):
         ),
     )
 
-    class Meta(object):
-        document = Bucket
+    class Meta:
+        """Meta"""
+
+        model = Bucket
         fields = ["label"]
