@@ -2,21 +2,24 @@
 """
 from unittest.case import TestCase
 
-from bson.objectid import ObjectId
-from django.core import exceptions as django_exceptions
 from django.test import override_settings
 from mock.mock import Mock, patch
 
-from core_composer_app.components.type import api as type_api
-from core_composer_app.components.type.models import Type
 from core_main_app.commons import exceptions
+from core_main_app.commons.exceptions import ModelError
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import create_mock_request
+from core_composer_app.components.type import api as type_api
+from core_composer_app.components.type.models import Type
 
 
 class TestTypeGet(TestCase):
+    """Test Type Get"""
+
     @patch.object(Type, "get_by_id")
     def test_type_get_returns_type(self, mock_get_by_id):
+        """test_type_get_returns_type"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -35,10 +38,12 @@ class TestTypeGet(TestCase):
     def test_template_get_raises_exception_if_object_does_not_exist(
         self, mock_get_by_id
     ):
+        """test_template_get_raises_exception_if_object_does_not_exist"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
-        mock_absent_id = ObjectId()
+        mock_absent_id = -1
         mock_get_by_id.side_effect = exceptions.DoesNotExist("")
 
         # Act + Assert
@@ -47,8 +52,12 @@ class TestTypeGet(TestCase):
 
 
 class TestTypeGetAll(TestCase):
+    """Test Type Get All"""
+
     @patch.object(Type, "get_all")
     def test_get_all_types_returns_types(self, mock_get_all):
+        """test_get_all_types_returns_types"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -65,8 +74,12 @@ class TestTypeGetAll(TestCase):
 
 
 class TestTypeGetAllComplexType(TestCase):
+    """Test Type Get All Complex Type"""
+
     @patch.object(Type, "get_all_complex_type")
     def test_get_all_types_returns_types(self, mock_get_all_complex_type):
+        """test_get_all_types_returns_types"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -83,9 +96,14 @@ class TestTypeGetAllComplexType(TestCase):
 
 
 class TestTypeUpsert(TestCase):
+    """Test Type Upsert"""
+
     @override_settings(ROOT_URLCONF="core_main_app.urls")
+    @patch.object(Type, "dependencies")
     @patch.object(Type, "save")
-    def test_type_upsert_valid_returns_type(self, mock_save):
+    def test_type_upsert_valid_returns_type(self, mock_save, mock_dependencies):
+        """test_type_upsert_valid_returns_type"""
+
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
         type_object = _create_type()
@@ -96,16 +114,20 @@ class TestTypeUpsert(TestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     @patch.object(Type, "save")
-    def test_type_upsert_invalid_filename_raises_validation_error(self, mock_save):
+    def test_type_upsert_invalid_filename_raises_model_error(self, mock_save):
+        """test_type_upsert_invalid_filename_raises_model_error"""
+
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
         type_object = _create_type(filename=1)
-        mock_save.side_effect = django_exceptions.ValidationError("")
-        with self.assertRaises(django_exceptions.ValidationError):
+        mock_save.side_effect = ModelError("")
+        with self.assertRaises(ModelError):
             type_api.upsert(type_object, request=mock_request)
 
     @patch.object(Type, "save")
     def test_type_upsert_invalid_core_type_raises_core_error(self, mock_save):
+        """test_type_upsert_invalid_core_type_raises_core_error"""
+
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
         type_object = _create_type(content="<schema></schema>")
@@ -127,11 +149,11 @@ def _create_mock_type(filename="", content=""):
     mock_type = Mock(spec=Type)
     mock_type.filename = filename
     mock_type.content = content
-    mock_type.id = ObjectId()
+    mock_type.id = 1
     return mock_type
 
 
-def _create_type(filename="", content=None):
+def _create_type(filename="Schema", content=None):
     """Returns a type
 
     Args:
@@ -148,4 +170,4 @@ def _create_type(filename="", content=None):
             "<restriction base='string'><enumeration value='test'/></restriction>"
             "</simpleType></schema>"
         )
-    return Type(id=ObjectId(), filename=filename, content=content)
+    return Type(id=1, filename=filename, content=content)
