@@ -2,28 +2,31 @@
 """
 from unittest.case import TestCase
 
-from bson.objectid import ObjectId
 from django.core import exceptions as django_exceptions
+from django.db import IntegrityError
 from django.test import override_settings
 from mock.mock import Mock, patch
-from mongoengine import errors as mongoengine_exceptions
 
+from core_main_app.commons.exceptions import CoreError, ModelError
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_app.utils.tests_tools.RequestMock import create_mock_request
 from core_composer_app.components.bucket.models import Bucket
 from core_composer_app.components.type.models import Type
 from core_composer_app.components.type_version_manager import api as version_manager_api
 from core_composer_app.components.type_version_manager.api import get_no_buckets_types
 from core_composer_app.components.type_version_manager.models import TypeVersionManager
-from core_main_app.commons.exceptions import CoreError, ModelError, NotUniqueError
-from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import create_mock_request
 
 
 class TestTypeVersionManagerInsert(TestCase):
+    """Test Type Version Manager Insert"""
+
     @patch.object(TypeVersionManager, "save")
     @patch.object(Type, "save")
     def test_create_version_manager_raises_exception_if_type_not_supported(
         self, mock_save_type, mock_save_type_version_manager
     ):
+        """test_create_version_manager_raises_exception_if_type_not_supported"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -43,11 +46,17 @@ class TestTypeVersionManagerInsert(TestCase):
             )
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
+    @patch.object(Type, "dependencies")
     @patch.object(TypeVersionManager, "save")
     @patch.object(Type, "save")
     def test_create_version_manager_returns_version_manager(
-        self, mock_save_type, mock_save_type_version_manager
+        self,
+        mock_save_type,
+        mock_save_type_version_manager,
+        mock_dependencies,
     ):
+        """test_create_version_manager_returns_version_manager"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -64,6 +73,8 @@ class TestTypeVersionManagerInsert(TestCase):
         version_manager = _create_type_version_manager(title="Schema")
         mock_save_type_version_manager.return_value = version_manager
 
+        mock_dependencies.return_value = MockDependencies()
+
         # Act
         result = version_manager_api.insert(
             version_manager, type_object, request=mock_request
@@ -73,12 +84,15 @@ class TestTypeVersionManagerInsert(TestCase):
         self.assertIsInstance(result, TypeVersionManager)
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
+    @patch.object(Type, "dependencies")
     @patch.object(Type, "delete")
-    @patch.object(Type, "save")
-    @patch.object(TypeVersionManager, "save")
+    @patch.object(Type, "save_template")
+    @patch.object(TypeVersionManager, "save_version_manager")
     def test_insert_manager_raises_api_error_if_title_already_exists(
-        self, mock_version_manager_save, mock_save, mock_delete
+        self, mock_version_manager_save, mock_save, mock_delete, mock_dependencies
     ):
+        """test_insert_manager_raises_api_error_if_title_already_exists"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -88,10 +102,12 @@ class TestTypeVersionManagerInsert(TestCase):
         mock_save.return_value = type_object
         mock_delete.return_value = None
         mock_version_manager = _create_type_version_manager(title="Schema")
-        mock_version_manager_save.side_effect = mongoengine_exceptions.NotUniqueError
+        mock_version_manager_save.side_effect = IntegrityError("")
+
+        mock_dependencies.return_value = MockDependencies()
 
         # Act + Assert
-        with self.assertRaises(NotUniqueError):
+        with self.assertRaises(IntegrityError):
             version_manager_api.insert(
                 mock_version_manager, type_object, request=mock_request
             )
@@ -101,6 +117,8 @@ class TestTypeVersionManagerInsert(TestCase):
     def test_create_version_manager_raises_exception_if_error_in_create_type(
         self, mock_save
     ):
+        """test_create_version_manager_raises_exception_if_error_in_create_type"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -108,21 +126,24 @@ class TestTypeVersionManagerInsert(TestCase):
         type_object = _create_type(type_filename)
 
         mock_version_manager = _create_mock_type_version_manager(title="Schema")
-        mock_save.side_effect = django_exceptions.ValidationError("")
+        mock_save.side_effect = ModelError("")
 
         # Act + Assert
-        with self.assertRaises(django_exceptions.ValidationError):
+        with self.assertRaises(ModelError):
             version_manager_api.insert(
                 mock_version_manager, type_object, request=mock_request
             )
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
+    @patch.object(Type, "dependencies")
     @patch.object(Type, "delete")
-    @patch.object(TypeVersionManager, "save")
-    @patch.object(Type, "save")
+    @patch.object(TypeVersionManager, "save_version_manager")
+    @patch.object(Type, "save_template")
     def test_create_version_manager_raises_exception_if_error_in_create_version_manager(
-        self, mock_save, mock_save_version_manager, mock_delete
+        self, mock_save, mock_save_version_manager, mock_delete, mock_dependencies
     ):
+        """test_create_version_manager_raises_exception_if_error_in_create_version_manager"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -135,17 +156,21 @@ class TestTypeVersionManagerInsert(TestCase):
         mock_delete.return_value = None
 
         # Act + Assert
-        with self.assertRaises(ModelError):
+        with self.assertRaises(django_exceptions.ValidationError):
             version_manager_api.insert(
                 version_manager, type_object, request=mock_request
             )
 
 
 class TestTypeVersionManagerGetGlobalVersions(TestCase):
+    """Test Type Version Manager Get Global Versions"""
+
     @patch.object(TypeVersionManager, "get_global_version_managers")
     def test_get_global_version_managers_returns_types(
         self, mock_get_global_version_managers
     ):
+        """test_get_global_version_managers_returns_types"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -161,10 +186,14 @@ class TestTypeVersionManagerGetGlobalVersions(TestCase):
 
 
 class TestTypeVersionManagerGetVersionManagersByUser(TestCase):
+    """Test Type Version Manager Get Version Manager By User"""
+
     @patch.object(TypeVersionManager, "get_version_managers_by_user")
     def test_get_version_managers_by_user_returns_types_with_given_user_id(
         self, mock_get_version_managers_by_user
     ):
+        """test_get_version_managers_by_user_returns_types_with_given_user_id"""
+
         # Arrange
         user_id = "10"
         mock_user = create_mock_user(user_id=user_id, is_superuser=True)
@@ -181,11 +210,15 @@ class TestTypeVersionManagerGetVersionManagersByUser(TestCase):
 
 
 class TestGetNoBucketsTypes(TestCase):
+    """Test Get No Buckets Types"""
+
     @patch.object(TypeVersionManager, "get_global_version_managers")
     @patch.object(Bucket, "get_all")
     def test_get_no_buckets_types_returns_types(
         self, mock_get_all_buckets, mock_get_global_version_managers
     ):
+        """test_get_no_buckets_types_returns_types"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -202,6 +235,8 @@ class TestGetNoBucketsTypes(TestCase):
     def test_get_no_buckets_types_returns_all_types_if_no_buckets(
         self, mock_get_all_buckets, mock_get_global_version_managers
     ):
+        """test_get_no_buckets_types_returns_all_types_if_no_buckets"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
@@ -217,13 +252,15 @@ class TestGetNoBucketsTypes(TestCase):
     def test_get_no_buckets_types_returns_all_types_not_in_buckets(
         self, mock_get_all_buckets, mock_get_global_version_managers
     ):
+        """test_get_no_buckets_types_returns_all_types_not_in_buckets"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
         mock_type1 = _create_mock_type_version_manager()
         mock_type2 = _create_mock_type_version_manager()
 
-        mock_bucket = _create_mock_bucket(types=[mock_type1])
+        mock_bucket = _create_mock_bucket(types=MockTypes([mock_type1]))
 
         mock_get_global_version_managers.return_value = [mock_type1, mock_type2]
         mock_get_all_buckets.return_value = [mock_bucket]
@@ -263,7 +300,7 @@ def _create_mock_type(filename="", content="", is_disable=False):
     mock_type = Mock(spec=Type)
     mock_type.filename = filename
     mock_type.content = content
-    mock_type.id = ObjectId()
+    mock_type.id = 1
     mock_type.is_disabled = is_disable
     return mock_type
 
@@ -280,7 +317,7 @@ def _create_mock_type_version_manager(title="", versions=None, user="1"):
     """
     mock_type_version_manager = Mock(spec=TypeVersionManager)
     mock_type_version_manager.title = title
-    mock_type_version_manager.id = ObjectId()
+    mock_type_version_manager.id = 1
     mock_type_version_manager.user = user
     if versions is not None:
         mock_type_version_manager.versions = versions
@@ -290,7 +327,7 @@ def _create_mock_type_version_manager(title="", versions=None, user="1"):
     return mock_type_version_manager
 
 
-def _create_type(filename="", content=None):
+def _create_type(filename="test", content=None):
     """Returns a type
 
     Args:
@@ -307,7 +344,7 @@ def _create_type(filename="", content=None):
             "<restriction base='string'><enumeration value='test'/></restriction>"
             "</simpleType></schema>"
         )
-    return Type(id=ObjectId(), filename=filename, content=content)
+    return Type(id=1, filename=filename, content=content)
 
 
 def _create_type_version_manager(title="", user="1"):
@@ -321,5 +358,38 @@ def _create_type_version_manager(title="", user="1"):
 
     """
     return TypeVersionManager(
-        id=ObjectId(), title=title, versions=[], user=user, disabled_versions=[]
+        id=1,
+        title=title,
+        user=user,
     )
+
+
+class MockDependencies:
+    """MockDependencies"""
+
+    def clear(self):
+        """Clear
+
+        Returns:
+
+        """
+        pass
+
+
+class MockTypes:
+    """MockTypes"""
+
+    def __init__(self, types):
+        self._types = types
+
+    def all(self):
+        """All
+        Returns:
+        """
+        return self._types
+
+    def count(self):
+        """Count
+        Returns:
+        """
+        return len(self._types)
